@@ -1,13 +1,23 @@
+"""Decorators"""
+
 import sys
 import time
 import traceback
 from functools import wraps
+from threading import Thread
 
-from .refact import print
 
 __all__ = list(globals())
 
 
+def main(f):
+    if len(sys.argv) == 1:
+        f()
+    for v in sys.argv[1:]:
+        f(v)
+    return f
+
+
 def timeit(f):
     @wraps(f)
     def wrapper(*args, **kwargs):
@@ -60,4 +70,19 @@ def surround(before=(), after=()):
     return decorator
 
 
+def hotkey(key='F12'):
+    key = key.lower()
+    def decorator(f):
+        def press(key2):
+            if key == str(key2).split('.')[-1].lower():
+                f()
+        def th():
+            import pynput
+            with pynput.keyboard.Listener(press) as kl:
+                kl.join()
+        Thread(target=th).start()
+        return f
+    return decorator
+
+
 __all__ = [k for k in globals() if k not in __all__]
