@@ -9,8 +9,6 @@ import traceback
 import urllib.parse
 import urllib.request
 
-from .refact import print
-
 # LOG = time.strftime('RECORD_%Y%m%d_%H%M%S.log')
 LOG = time.strftime('LOG_%Y%m%d_%H%M%S.txt')
 
@@ -28,7 +26,7 @@ def tag():
 
 
 def log(*value):
-    s = tag() + print(*value)
+    s = tag() + ' '.join(map(str, value))
     with open(LOG, 'a', encoding='u8') as f:
         f.write(s)
 
@@ -118,12 +116,6 @@ def bytes_hex(data, offset=0, length=-1, slice=-1):
     return s
 
 
-def argv_run(func, *defaults):
-    sys.argv.extend(defaults)
-    for file in sys.argv[1:]:
-        func(file)
-
-
 def install(path, block=False):
     p = os.popen('pip install "%s"' % path)
     if block:
